@@ -19,8 +19,7 @@
 #include "eckit/message/Decoder.h"
 #include "eckit/message/MessageContent.h"
 
-namespace eckit {
-namespace message {
+namespace eckit::message {
 
 MessageContent::operator bool() const {
     return true;
@@ -62,12 +61,24 @@ void MessageContent::getDoubleArray(const std::string& key, std::vector<double>&
     throw eckit::SeriousBug(oss.str());
 }
 
+void MessageContent::getFloatArray(const std::string& key, std::vector<float>&) const {
+    std::ostringstream oss;
+    oss << "Not implemented " << *this << " getFloatArray(key, vector<float>&)";
+    throw eckit::SeriousBug(oss.str());
+}
+
 void MessageContent::getDoubleArray(const std::string& key, double* data, size_t len) const {
     std::ostringstream oss;
     oss << "Not implemented " << *this << " getDoubleArray(key, double*, len)";
     throw eckit::SeriousBug(oss.str());
 }
 
+void MessageContent::getFloatArray(const std::string& key, float* data, size_t len) const {
+    std::ostringstream oss;
+    oss << "Not implemented " << *this << " getFloatArray(key, float*, len)";
+    throw eckit::SeriousBug(oss.str());
+}
+
 size_t MessageContent::getSize(const std::string& key) const {
     std::ostringstream oss;
     oss << "Not implemented " << *this << " getSize(key)";
@@ -104,5 +115,4 @@ MessageContent* MessageContent::transform(const StringDict&) const {
     throw eckit::SeriousBug(oss.str());
 }
 
-}  // namespace message
-}  // namespace eckit
+}  // namespace eckit::message
